==> kubernetes-model-batch-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/PodFailurePolicyRuleFluent.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodFailurePolicyRuleFluent<A extends PodFailurePolicyRuleFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  
  /**
   * This method has been deprecated, please use method buildOnExitCodes instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodFailurePolicyOnExitCodesRequirement getOnExitCodes();
  public PodFailurePolicyOnExitCodesRequirement buildOnExitCodes();
  public A withOnExitCodes(PodFailurePolicyOnExitCodesRequirement onExitCodes);
  public Boolean hasOnExitCodes();
  public PodFailurePolicyRuleFluent.OnExitCodesNested<A> withNewOnExitCodes();
  public PodFailurePolicyRuleFluent.OnExitCodesNested<A> withNewOnExitCodesLike(PodFailurePolicyOnExitCodesRequirement item);
  public PodFailurePolicyRuleFluent.OnExitCodesNested<A> editOnExitCodes();
  public PodFailurePolicyRuleFluent.OnExitCodesNested<A> editOrNewOnExitCodes();
  public PodFailurePolicyRuleFluent.OnExitCodesNested<A> editOrNewOnExitCodesLike(PodFailurePolicyOnExitCodesRequirement item);
  public A addToOnPodConditions(Integer index,PodFailurePolicyOnPodConditionsPattern item);
  public A setToOnPodConditions(Integer index,PodFailurePolicyOnPodConditionsPattern item);
  public A addToOnPodConditions(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyOnPodConditionsPattern... items);
  public A addAllToOnPodConditions(Collection<PodFailurePolicyOnPodConditionsPattern> items);
  public A removeFromOnPodConditions(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyOnPodConditionsPattern... items);
  public A removeAllFromOnPodConditions(Collection<PodFailurePolicyOnPodConditionsPattern> items);
  public A removeMatchingFromOnPodConditions(Predicate<PodFailurePolicyOnPodConditionsPatternBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildOnPodConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodFailurePolicyOnPodConditionsPattern> getOnPodConditions();
  public List<PodFailurePolicyOnPodConditionsPattern> buildOnPodConditions();
  public PodFailurePolicyOnPodConditionsPattern buildOnPodCondition(Integer index);
  public PodFailurePolicyOnPodConditionsPattern buildFirstOnPodCondition();
  public PodFailurePolicyOnPodConditionsPattern buildLastOnPodCondition();
  public PodFailurePolicyOnPodConditionsPattern buildMatchingOnPodCondition(Predicate<PodFailurePolicyOnPodConditionsPatternBuilder> predicate);
  public Boolean hasMatchingOnPodCondition(Predicate<PodFailurePolicyOnPodConditionsPatternBuilder> predicate);
  public A withOnPodConditions(List<PodFailurePolicyOnPodConditionsPattern> onPodConditions);
  public A withOnPodConditions(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyOnPodConditionsPattern... onPodConditions);
  public Boolean hasOnPodConditions();
  public A addNewOnPodCondition(String status,String type);
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> addNewOnPodCondition();
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> addNewOnPodConditionLike(PodFailurePolicyOnPodConditionsPattern item);
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> setNewOnPodConditionLike(Integer index,PodFailurePolicyOnPodConditionsPattern item);
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> editOnPodCondition(Integer index);
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> editFirstOnPodCondition();
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> editLastOnPodCondition();
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> editMatchingOnPodCondition(Predicate<PodFailurePolicyOnPodConditionsPatternBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface OnExitCodesNested<N> extends Nested<N>,PodFailurePolicyOnExitCodesRequirementFluent<PodFailurePolicyRuleFluent.OnExitCodesNested<N>>{
    public N and();
    public N endOnExitCodes();
    
  }
  public interface OnPodConditionsNested<N> extends Nested<N>,PodFailurePolicyOnPodConditionsPatternFluent<PodFailurePolicyRuleFluent.OnPodConditionsNested<N>>{
    public N and();
    public N endOnPodCondition();
    
  }
  
}

==> kubernetes-model-batch-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/PodFailurePolicyRuleFluent.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodFailurePolicyRuleFluent<A extends PodFailurePolicyRuleFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  
  /**
   * This method has been deprecated, please use method buildOnExitCodes instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodFailurePolicyOnExitCodesRequirement getOnExitCodes();
  public PodFailurePolicyOnExitCodesRequirement buildOnExitCodes();
  public A withOnExitCodes(PodFailurePolicyOnExitCodesRequirement onExitCodes);
  public Boolean hasOnExitCodes();
  public PodFailurePolicyRuleFluent.OnExitCodesNested<A> withNewOnExitCodes();
  public PodFailurePolicyRuleFluent.OnExitCodesNested<A> withNewOnExitCodesLike(PodFailurePolicyOnExitCodesRequirement item);
  public PodFailurePolicyRuleFluent.OnExitCodesNested<A> editOnExitCodes();
  public PodFailurePolicyRuleFluent.OnExitCodesNested<A> editOrNewOnExitCodes();
  public PodFailurePolicyRuleFluent.OnExitCodesNested<A> editOrNewOnExitCodesLike(PodFailurePolicyOnExitCodesRequirement item);
  public A addToOnPodConditions(int index,PodFailurePolicyOnPodConditionsPattern item);
  public A setToOnPodConditions(int index,PodFailurePolicyOnPodConditionsPattern item);
  public A addToOnPodConditions(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyOnPodConditionsPattern... items);
  public A addAllToOnPodConditions(Collection<PodFailurePolicyOnPodConditionsPattern> items);
  public A removeFromOnPodConditions(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyOnPodConditionsPattern... items);
  public A removeAllFromOnPodConditions(Collection<PodFailurePolicyOnPodConditionsPattern> items);
  public A removeMatchingFromOnPodConditions(Predicate<PodFailurePolicyOnPodConditionsPatternBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildOnPodConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodFailurePolicyOnPodConditionsPattern> getOnPodConditions();
  public List<PodFailurePolicyOnPodConditionsPattern> buildOnPodConditions();
  public PodFailurePolicyOnPodConditionsPattern buildOnPodCondition(int index);
  public PodFailurePolicyOnPodConditionsPattern buildFirstOnPodCondition();
  public PodFailurePolicyOnPodConditionsPattern buildLastOnPodCondition();
  public PodFailurePolicyOnPodConditionsPattern buildMatchingOnPodCondition(Predicate<PodFailurePolicyOnPodConditionsPatternBuilder> predicate);
  public Boolean hasMatchingOnPodCondition(Predicate<PodFailurePolicyOnPodConditionsPatternBuilder> predicate);
  public A withOnPodConditions(List<PodFailurePolicyOnPodConditionsPattern> onPodConditions);
  public A withOnPodConditions(io.fabric8.kubernetes.api.model.batch.v1.PodFailurePolicyOnPodConditionsPattern... onPodConditions);
  public Boolean hasOnPodConditions();
  public A addNewOnPodCondition(String status,String type);
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> addNewOnPodCondition();
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> addNewOnPodConditionLike(PodFailurePolicyOnPodConditionsPattern item);
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> setNewOnPodConditionLike(int index,PodFailurePolicyOnPodConditionsPattern item);
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> editOnPodCondition(int index);
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> editFirstOnPodCondition();
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> editLastOnPodCondition();
  public PodFailurePolicyRuleFluent.OnPodConditionsNested<A> editMatchingOnPodCondition(Predicate<PodFailurePolicyOnPodConditionsPatternBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface OnExitCodesNested<N> extends Nested<N>,PodFailurePolicyOnExitCodesRequirementFluent<PodFailurePolicyRuleFluent.OnExitCodesNested<N>>{
    public N and();
    public N endOnExitCodes();
    
  }
  public interface OnPodConditionsNested<N> extends Nested<N>,PodFailurePolicyOnPodConditionsPatternFluent<PodFailurePolicyRuleFluent.OnPodConditionsNested<N>>{
    public N and();
    public N endOnPodCondition();
    
  }
  
}
